@@ -5,12 +5,12 @@ package Getopt::GUI::Long;
 
 use strict;
 use Text::Wrap;
-use Getopt::Long qw(Configure);
+use Getopt::Long qw();
 use QWizard;
 use QWizard::Storage::File;
 use File::Temp qw(tempfile);
 
-our $VERSION="0.4";
+our $VERSION="0.5";
 
 require Exporter;
 
@@ -77,6 +77,8 @@ sub GetOptions(@) {
 
     my $progname = $main::0;
     my $cache;
+    my %GUI_info;
+
     $progname =~ s/([^a-zA-Z0-9])/'_' . ord($1)/eg;
     my $cachefile = "$ENV{HOME}/.GetoptLongGUI/$progname";
     if (-f $cachefile) {
@@ -93,7 +95,15 @@ sub GetOptions(@) {
 	my @names;
 	my %names;
 	my @qs;
-	my %GUI_info;
+	my $screencount = 0;
+	my @saveqs;
+	my $pris;
+	
+	# Define the first screen
+	$pris->{'screen' . $screencount} =
+	  { title => "Options for $main::0",
+	  };
+
 	for (my $i = $st; $i <= $#opts; $i += $cb) {
 	    my ($spec, $desc, %rest);
 	    if (ref($opts[$i]) eq 'ARRAY') {
@@ -109,12 +119,56 @@ sub GetOptions(@) {
 
 	    if ($spec =~ /^GUI:(.*)/) {
 		my $guiname = $1;
-		if ($guiname =~ /guionly/) {
+		
+		if ($guiname eq "guionly") {
+		    #
+		    # a specific QWizard question to be added
+		    #
 		    push @qs,
 		      set_default_opt($cache,@{$opts[$i]}[1..$#{$opts[$i]}]);
-		} elsif ($guiname =~ /separator/) {
-		    push @qs, { type => 'label', text => $opts[$i][1]};
+
+		} elsif ($guiname eq "separator") {
+		    #
+		    # add a separator label.
+		    #
+		    push @qs, "", { type => 'label', text => $opts[$i][1]};
+
+		} elsif ($guiname eq "screen") {
+		    #
+		    # Start a brand new screen
+		    #
+
+		    # If the screen is optional via a previous flag
+		    if (exists($rest{'doif'}) &&
+			ref($rest{'doif'}) ne 'CODE') {
+			$rest{'doifstr'} = $rest{'doif'};
+			$rest{'doif'} = 
+			  sub { return qwparam($_[2]{'doifstr'})};
+		    }
+
+		    # Define the new screen
+		    if ($#qs == -1) {
+			# screen definition occured before the first
+			# question, have this only affect the current
+			# screen.
+			foreach my $tok (keys(%rest)) {
+			    $pris->{'screen' . $screencount}{$tok} = 
+			      $rest{$tok};
+			}
+			# maybe set the title
+			$pris->{'screen' . $screencount}{'title'} = $desc
+			  if ($desc);
+		    } else {
+			$pris->{'screen' . $screencount}{'questions'} = [@qs];
+			$screencount++;
+			$pris->{'screen' . $screencount} =
+			  { title => $desc || "Options for $main::0",
+			    # allow user to override
+			    %rest };
+			@qs = ();
+		    }
 		} else {
+		    # generic GUI config token; store the name
 		    @{$GUI_info{$guiname}} = @{$opts[$i]}[1..$#{$opts[$i]}];
 		}
 		next;
@@ -143,7 +197,7 @@ sub GetOptions(@) {
                      # ... or an optional-with-default spec
                      : (?: -?\d+ | \+ ) [@%]?
                    )?
-			  $;x;
+		       $;x;
 
 	    # map option pieces into variables
 	    my ($pat, $optname, $firstname, $args) = ($1, $2, $3, $4);
@@ -174,7 +228,9 @@ sub GetOptions(@) {
 			   $opts[$i+1]);
 	    }
 
+	    #
 	    # Now constructure the needed GUI question
+	    #
 	    if ($rest{'question'}) {
 		# if a QWizard question definition was passed to us, use that.
 		if (ref($rest{'question'}) ne 'ARRAY') {
@@ -185,7 +241,7 @@ sub GetOptions(@) {
 		    $_->{'text'} = $desc if ($_->{'text'} eq '');
 		    $_->{'default'} = $defval if (!exists($_->{'default'}));
 		} @{$rest{'question'}};
-		push @qs, set_default_opt(@{$rest{'question'}});
+		push @qs, set_default_opt($cache, @{$rest{'question'}});
 
 	    } elsif ($desc =~ /^!GUI/) {
 		# if the description was marked as not-for-the-GUI, don't
@@ -193,7 +249,9 @@ sub GetOptions(@) {
 		push @qs, {type => 'hidden', name => $name, default => $defval};
 
 	    } elsif (!$args || $args =~ /[!+]/) {
-		# The option was a boolean flag: use a checkbox
+		#
+		# Boolean => Checkbox
+		#
 		push @qs,
 		  {
 		   'text' => $desc,
@@ -202,9 +260,11 @@ sub GetOptions(@) {
 		   default => (($defval)?1:undef),
 		   'name' => $name,
 		  };
+
 	    } elsif ($args =~ /i/) {
-		# The option was an integer, use a entry with a forced
-		# integer type check
+		#
+		# Integer => textbox with int check
+		#
 		push @qs,
 		  {
 		   'text' => $desc,
@@ -215,7 +275,9 @@ sub GetOptions(@) {
 				   \&qw_integer : \&qw_optional_integer),
 		  };
 	    } elsif ($args =~ /[sf]/) {
-		# The option was a string or float, allow anything.
+		#
+		# Float/string => textbox
+		#
 		# XXX: deal with floats seperately
 		push @qs,
 		  {
@@ -225,8 +287,9 @@ sub GetOptions(@) {
 		   'name' => $name,
 		  };
 	    } else {
-		# In theory we probably shouldn't get here.  But fake
-		# it if we do.
+		#
+		# Unknown => textbox
+		#
 		push @qs,
 		  {
 		   'text' => $desc,
@@ -242,21 +305,6 @@ sub GetOptions(@) {
 	    }
 	}
 
-	# Prompt for remaining arguments (or don't if requested to
-	# skip it).  Normally this would be stuff handled beyond the
-	# realm of the Getopt processing like file-names, etc.
-	if ($GUI_info{'nootherargs'}) {
-	    push @qs, "", { type => 'hidden', name => '__otherargs' };
-	} else {
-	    push @qs, "", { type => 'text',
-			    width => 80,
-			    name => '__otherargs',
-			    default => 
-			    ($cache) ? $cache->get('__otherargs') : '',
-			    text =>
-			    $GUI_info{'otherargs_text'} || "Other Arguments" };
-	}
-
 	# offer a save options button
 	push @qs, "", 
 	  { type => 'button',
@@ -265,61 +313,101 @@ sub GetOptions(@) {
 	    default => 1,
 	    values => 'Save and continue'};
 
-	# build primaries based on everything passed to us.
-	my $pris;
-
 	# include other primary information passed to us
 	if (exists($GUI_info{'otherprimaries'})) {
 	    %$pris = @{$GUI_info{'otherprimaries'}};
 	}
 
-	# our master primary
-	$pris->{'getopts'} =
-	  {
-	   questions => \@qs,
-	   title => "Select options for $main::0",
-	   post_answers => [[sub {
-				 my ($wiz, $cache, $cachefile) = @_;
-				 if (qwparam('savethese')) {
-				     if (! -d "$ENV{HOME}/.GetoptLongGUI") {
-					 mkdir("$ENV{HOME}/.GetoptLongGUI");
-				     }
-				     if (!$cache) {
-					 $cache = new QWizard::Storage::File (file => $cachefile);
-				     }
-				     $cache->copy_from($wiz->{'generator'}{'datastore'});
-				 }
-			     }, $cache, $cachefile]],
-	   actions => [[sub {
-			    my $qw = shift;
-			    for (my $i = 0; $i <= $#{$_[0]}; $i++) {
-				if (qwparam($_[0][$i])) {
-				    if (!$_[1]{$_[0][$i]} ||
-					$_[1]{$_[0][$i]} =~ /[+!]/) {
-					push @main::ARGV,
-					  "--" . $_[0][$i];
-				    } else {
-					push @main::ARGV,
-					  "--" . $_[0][$i],
-					    qwparam($_[0][$i]);
-				    }
-				}
-			    }
-			    push @main::ARGV,
-			      split(/\s+/,qwparam('__otherargs'));
-			    return 'OK';
-			}, \@names, \%names]],
-	  };
+	# Prompt for remaining arguments (or don't if requested to
+	# skip it).  Normally this would be stuff handled beyond the
+	# realm of the Getopt processing like file-names, etc.
+	if ($GUI_info{'nootherargs'}) {
+	    push @{$pris->{'screen0'}{'questions'}},
+	      "", { type => 'hidden', name => '__otherargs' };
+	} else {
+	    my $q = { type => 'text',
+		      width => 80,
+		      name => '__otherargs',
+		      default => 
+		      ($cache) ? $cache->get('__otherargs') : '',
+		      text =>
+		      $GUI_info{'otherargs_text'} || "Other Arguments",
+		    };
+	    if ($GUI_info{'otherargs_required'}) {
+		$q->{'check_value'} = \&qw_required_field;
+	    }
+	    push @{$pris->{'screen0'}{'questions'}}, "", $q;
+	  }
 
+	# our last primary setup
+	$pris->{'screen' . $screencount}{'questions'} = [@qs];
+	push @{$pris->{'screen' . $screencount}{'post_answers'}},
+	  [sub {
+	       my ($wiz, $cache, $cachefile) = @_;
+		
+	       #
+	       # if they requested the values be
+	       # saved as defaults store them to a file.
+	       #
+	       if (qwparam('savethese')) {
+		   if (! -d "$ENV{HOME}/.GetoptLongGUI") {
+		       mkdir("$ENV{HOME}/.GetoptLongGUI");
+		   }
+		   if (!$cache) {
+		       $cache = new QWizard::Storage::File (file => $cachefile);
+		   }
+		   $cache->copy_from($wiz->{'generator'}{'datastore'});
+	       }
+	   }, $cache, $cachefile];
+
+	push @{$pris->{'screen' . $screencount}{'actions'}},
+	  [sub {
+	       #
+	       # map all the defined option names from
+	       # qwparam values pulled from the GUI back
+	       # into ARGV options to be passed to
+	       # Getopt::Long for processing
+	       #
+	       my ($qw, $name_array, $name_hash) = @_;
+	       for (my $i = 0; $i <= $#{$name_array}; $i++) {
+		   if (qwparam($name_array->[$i])) {
+		       if (!$name_hash->{$name_array->[$i]} ||
+			   $name_hash->{$name_array->[$i]} =~ /[+!]/) {
+			   push @main::ARGV,
+			     "--" . $name_array->[$i];
+		       } else {
+			   push @main::ARGV,
+			     "--" . $name_array->[$i],
+			       qwparam($name_array->[$i]);
+		       }
+		   }
+	       }
+	       push @main::ARGV,
+		 split(/\s+/,qwparam('__otherargs'));
+	       return 'OK';
+	   }, \@names, \%names];
+
+	# add in later screens if needed
+	if ($screencount > 0) {
+	    push @{$pris->{'screen0'}{'post_answers'}},
+	      [sub {
+		   my ($wiz, $screencount) = @_;
+		   for (my $i = $screencount; $i >= 1; $i--) {
+		       $wiz->add_todos('screen' .$i);
+		   }
+	       }, $screencount];
+	}
+	
 	# add in an post_answers clauses to the master primary
+	# XXX: move to each screen def
 	if ($GUI_info{'post_answers'}) {
-	    push @{$pris->{'getopts'}{'post_answers'}},
+	    push @{$pris->{'screen0'}{'post_answers'}},
 	      @{$GUI_info{'post_answers'}};
 	}
 
 	# add in an actions clauses to the master primary
 	if ($GUI_info{'actions'}) {
-	    unshift @{$pris->{'getopts'}{'actions'}}, @{$GUI_info{'actions'}};
+	    unshift @{$pris->{'screen0'}{'actions'}}, @{$GUI_info{'actions'}};
 	}
 
 	# Finally, construct the QWizard GUI class...
@@ -335,7 +423,7 @@ sub GetOptions(@) {
 	$qw->merge_primaries(\%primaries);
 
 	# ... and tell it to go
-	$qw->magic('getopts', @{$GUI_info{'submodules'}});
+	$qw->magic('screen0', @{$GUI_info{'submodules'}});
 
 
 	# ... if we aren't finished processing then exit.  This should
@@ -382,75 +470,146 @@ sub GetOptions(@) {
 	*STDERR = $config{'fh'};
     }
 
-    # Print help message if auto_help is on (XXX)
     if (defined($config{'display_help'}) &&
-	ref($_[0]) eq 'HASH' && ($_[0]{'help'} || $_[0]{'h'})) {
-	# print usage information
-	print STDERR "Usage for: $0\n";
-	for (my $i = $st; $i <= $#savedopts; $i += $cb) {
-	    my ($spec, $desc, %rest);
-	    if (ref($savedopts[$i]) eq 'ARRAY') {
-		$spec = $savedopts[$i][0];
-		$desc = $savedopts[$i][1];
-		%rest = @{$savedopts[$i]}[2..$#{$savedopts[$i]}];
-	    } elsif ($savedopts[$i] eq '') {
-		print "\n";
-	    } else {
-		$spec = $savedopts[$i];
-	    }
+	ref($_[0]) eq 'HASH' &&
+	($_[0]{'help'} || $_[0]{'help-full'} || $_[0]{'h'})) {
+	display_help($st, $cb, \%GUI_info, \@savedopts, @_);
+    }
+    return $ret;
+}
 
-	    next if ($spec =~ /^GUI:(.*)/);
+#
+# prints help information
+#
+sub display_help {
+    my $st = shift;
+    my $cb = shift;
+    my $GUI_info = shift;
+    my $savedopts = shift;
+    # Print help message if auto_help is on (XXX)
 
-	    # regexp stolen (and modified) from Getopt::Long
-	    # XXX: copy copyright
-	    $spec =~ m;^
-		       # $1 = whole name pattern
-		       (
-		       # $2 = Option name
-		       (\w+[-\w]* )
-		       # $3 = first name, or "?"
-		       (?: \| (\? | \w[-\w]* )? )?
-		       # Alias names, or "?"
-		       (?: \| (?: \? | \w[-\w]* )? )*
-		      )?
-		       # $4 = arguments
-		       (
-		       # Either modifiers ...
-		       [!+]
-		       |
-		       # ... or a value/dest specification
-		       [=:] [ionfs] [@%]?
-		       |
-		       # ... or an optional-with-default spec
-		       : (?: -?\d+ | \+ ) [@%]?
-		      )?
-		       $;x;
+    print STDERR "Usage: $0 [OPTIONS] ",
+      ($GUI_info->{'otherargs_text'} ||
+       ($GUI_info->{'nootherargs'} ? "" : "Other Arguments")),
+	 "\n\nOPTIONS:\n";
 
-	    # map option pieces into variables
-	    my ($pat, $optname, $firstname, $argspec) = ($1, $2, $3, $4);
+    for (my $i = $st; $i <= $#{$savedopts}; $i += $cb) {
+	my ($spec, $desc, %rest);
+	if (ref($savedopts->[$i]) eq 'ARRAY') {
+	    $spec = $savedopts->[$i][0];
+	    $desc = $savedopts->[$i][1];
+	    %rest = @{$savedopts->[$i]}[2..$#{$savedopts->[$i]}];
+	} elsif ($savedopts->[$i] eq '') {
+	    print STDERR "\n";
+	    next;
+	} else {
+	    $spec = $savedopts->[$i];
+	}
 
-	    # turn argspecs into human consumable versions.
-	    if ($argspec =~ /i/) {
-		$argspec = "=INTEGER";
-	    } elsif ($argspec =~ /f/) {
-		$argspec = "=FLOAT";
-	    } elsif ($argspec =~ /s/) {
-		$argspec = "=STRING";
-	    } else {
-		$argspec = "";
-	    }
+	# print separators
+	if ($spec =~ /^GUI:(separator|screen)/) {
+	    print STDERR "\n$desc\n";
+	    next;
+	}
 
-	    my @args=split(/\|/,$pat);
+	next if ($spec =~ /^GUI:(.*)/);
+
+	# regexp stolen (and modified) from Getopt::Long
+	# XXX: copy copyright
+	$spec =~ m;^
+		   # $1 = whole name pattern
+		   (
+		   # $2 = Option name
+		   (\w+[-\w]* )
+		   # $3 = first name, or "?"
+		   (?: \| (\? | \w[-\w]* )? )?
+		   # Alias names, or "?"
+		   (?: \| (?: \? | \w[-\w]* )? )*
+		  )?
+		   # $4 = arguments
+		   (
+		   # Either modifiers ...
+		   [!+]
+		   |
+		   # ... or a value/dest specification
+		   [=:] [ionfs] [@%]?
+		   |
+		   # ... or an optional-with-default spec
+		   : (?: -?\d+ | \+ ) [@%]?
+		  )?
+		   $;x;
+
+	# map option pieces into variables
+	my ($pat, $optname, $firstname, $argspec) = ($1, $2, $3, $4);
+
+	# turn argspecs into human consumable versions.
+	if ($argspec =~ /i/) {
+	    $argspec = "INTEGER";
+	} elsif ($argspec =~ /f/) {
+	    $argspec = "FLOAT";
+	} elsif ($argspec =~ /s/) {
+	    $argspec = "STRING";
+	} else {
+	    $argspec = "";
+	}
+
+	my @args=split(/\|/,$pat);
+	if ($_[0]{'help-full'}) {
+	    # they want *everything*
 	    for (my $argc=0;  $argc <= $#args; $argc++) {
-		printf STDERR ("  --%-20s %-55s\n",
-			       $args[$argc] . $argspec,
-			       ($argc == $#args)?$desc:"");
+		_display_help_option($args[$argc], $argspec,
+				     ($argc == $#args)?$desc:"");
+	    }
+
+	} elsif ($_[0]{'h'}) {
+	    # assume short names perferred and always show the shortest
+	    _display_help_option($args[0], $argspec, $desc);
+
+	} elsif ($_[0]{'help'}) {
+	    # assume long names perferred and use those if possible
+	    if ($#args == 0) {
+		# only one is avialable
+		_display_help_option($args[0], $argspec, $desc);
+	    } elsif (length($args[0]) == 1) {
+		# first one is short, display the second...
+		_display_help_option_long($args[1], $argspec, $desc);
+	    } else {
+		# first one itself is long, display it.
+		_display_help_option_long($args[0], $argspec, $desc);
 	    }
 	}
-	exit(1);
     }
 
-    return $ret;
+    # display the display_help options
+    print STDERR "\nHelp Options:\n";
+    _display_help_option_short('h','',
+			       'Display help options -- short flags preferred');
+    _display_help_option_long('help','',
+			       'Display help options -- long flags preferred');
+    _display_help_option_long('help-full','',
+			       'Display all help options -- short and long');
+
+    exit(1);
+}
+
+sub _display_help_option {
+    my ($arg,$spec,$desc) = @_;
+    if (length($arg) == 1) {
+	_display_help_option_short(@_);
+    } else {
+	_display_help_option_long(@_);
+    }
+}
+
+sub _display_help_option_short {
+    my ($arg,$spec,$desc) = @_;
+    printf STDERR ("   -%-20s %-55s\n", $arg . " " . $spec, $desc);
+}
+
+sub _display_help_option_long {
+    my ($arg,$spec,$desc) = @_;
+    printf STDERR ("  --%-20s %-55s\n",
+		   $arg . ($spec ? "=" : "") . $spec, $desc);
 }
 
 sub MapToGetoptLong {
@@ -463,10 +622,14 @@ sub MapToGetoptLong {
 	    push @opts, $_[$i+1] if ($cb == 2);
 	}
     }
-
+    push @opts,GetHelpOptions() if ($config{'display_help'});
     return @opts;
 }
 
+sub GetHelpOptions {
+    return ('help','h','help-full');
+}
+
 #
 # Configure's the running operation of the module.  Any unknown
 # arguments are passed to the parent Configure script.
@@ -524,25 +687,78 @@ Getopt::GUI::Long
   # pass useful config options to Configure
   Getopt::GUI::Long::Configure(qw(display_help no_ignore_case capture_output));
   GetOptions(\%opts,
-	     ["h|help", "Show help for command line options"],
-	     ["some-flag=s", "perform some flag based on a value"]);
+             ["GUI:separator",   "Important Flags:"],
+	     ["f|some-flag=s",   "A flag based on a string"],
+	     ["o|other-flag",    "A boloean"],
+            );
 
-  # or
+  # or use references instead of a hash (less tested, however):
 
-  GetOptions(["h|help", "Show help for command line options"] => \$help,
-	     ["some-flag=s", "perform some flag based on a value"] => \$flag);
+  GetOptions(["some-flag=s",  "perform some flag based on a value"] => \$flag,
+             ["other-flag=s", "perform some flag based on a value"] => \$other);
 
+  # displays auto-help given the input above:
+
+  % opttest -h
+  Usage: opttest [OPTIONS] Other Arguments
+
+  OPTIONS:
+
+  Important Flags:
+     -f STRING             A flag based on a string
+     -o                    A boloean
+
+  Help Options:
+     -h                    Display help options -- short flags preferred
+    --help                 Display help options -- long flags preferred
+    --help-full            Display all help options -- short and long
+
+
+
+  # or long help:
+
+  % opttest --help
+  Usage: opttest [OPTIONS] Other Arguments
+
+  OPTIONS:
+
+  Important Flags:
+    --some-flag=STRING     A flag based on a string
+    --other-flag           A boloean
+
+  Help Options:
+     -h                    Display help options -- short flags preferred
+    --help                 Display help options -- long flags preferred
+    --help-full            Display all help options -- short and long
+
+  # or a GUI screen:
+
+  (see http://net-policy.sourceforge.net/images/getopt_example.png )
 
 =head1 DESCRIPTION
 
+  This module is a wrapper around Getopt::Long that extends the value of
+  the original Getopt::Long module to:
 
-This module is a wrapper around Getopt::Long that extends the value of
-the originial Getopt::Long module to add a simple graphical user
-interface option screen if no arguments are passed to the program.
-Thus, the arguments to actually use are built based on the results of
-the user interface. If arguments were passed to the program, the user
-interface is not shown and the program executes as it normally would
-and acts just as if Getopt::Long::GetOptions had been called instead.
+  1) add a simple graphical user interface option screen if no
+     arguments are passed to the program.  Thus, the arguments to
+     actually use are built based on the results of the user
+     interface. If arguments were passed to the program, the user
+     interface is not shown and the program executes as it normally
+     would and acts just as if Getopt::Long::GetOptions had been
+     called instead.
+
+  2) provide an auto-help mechanism such that -h and --help are
+     handled automatically.  In fact, calling your program with -h
+     will default to showing the user a list of short-style arguments
+     when one exists for the option.  Similarly --help will show the
+     user a list of long-style when possible.  --help-full will list
+     all potential arguments for an option (short and long both).
+
+  It's designed to make the creation of graphical shells trivial
+  without the programmer having to think about it much as well as
+  providing automatic good-looking usage output without the
+  programmer needing to write usage() functions.
 
 =head1 HISTORY
 
@@ -555,8 +771,9 @@ works of course.
 
 =head1 USAGE
 
-The Getopt::GUI::Long module works identically to the Getopt::Long
-module, but does offer a few extra features.
+The Getopt::GUI::Long module can work identically to the Getopt::Long
+module but really benefits from some slightly different usage
+conventions described below.
 
 =head2 Option format:
 
@@ -604,12 +821,32 @@ displayed (automatically at least) within the GUI.
 
 =item 2...: OTHER options
 
+Beyond the name and description, key value pairs can indicate more
+about how the option should be handled.
+
 =over
 
 =item required => 1
 
 Forces a screen option to be filled out by the user.
 
+=item question => { QUESTION FORM }
+
+=item question => [{ QUESTION1}, {QUESTION2}, ...]
+
+These allows you to build custom QWizard widgets to meet a particular
+question need.  It's highly useful for doing menus and single choice
+fields that normally command line options don't handle well.  For
+example consider a numeric priority level between 0 and 10.  The
+following question definition will give them a menu rather than a fill
+in the blank field:
+
+  ['priority=i','Priority Level',
+   question => { type => 'menu', values => [1..10] }]
+
+Note you can specify multiple question widgets if needed as well,
+though this will probably be rare in usage.
+
 =back
 
 [others TBD]
@@ -622,8 +859,12 @@ Forces a screen option to be filled out by the user.
 
 Flags that start with GUI: are not passed to the normal Getopt::Long
 routines and are instead for internal GUI digestion only.  If the GUI
-screen is going to be displayed (remember: the user didn't specify any
-options), these extra options control how the GUI behaves.
+screen is going to be displayed (remember: only if the user didn't
+specify any options), these extra options control how the GUI behaves.
+
+Some of these options requires some knowledge of the QWizard
+programming system.  Knowledge of QWizard should only be required if
+you want to make use of those particular extra features.
 
 =over
 
@@ -641,6 +882,39 @@ usage.
 
 Inserts a label above a set of options to identify them as a group.
 
+=item GUI:screen
+
+  EG:  ['GUI:screen', 'Next Screen Title', ...]
+
+Specifies that a break in the option requests should occur and the
+remaining options should appear on another screen(s).  This allows
+applications with a lot of options to reduce the complexity it offers
+users and offers a more "wizard" like approach to helping them decide
+what they're trying to do.
+
+You can also make this next screen definition conditional by defining
+an earlier option that may be, say, a boolean flag called
+"feature_flag".  Using this you can then only go into the next screen
+if the "feature_flag" was set by doing the following:
+
+        ['feature-flag',
+         'turn on a special feature needing more options'],
+
+        ['GUI:screen', 'Next Screen Title', doif => 'feature-flag']
+        ['feature-arg1', 'extra argument #1 for special feature'],
+        ...
+
+Also, if you need to do more complex calculations use the qwparam()
+function of the passed in QWizard object in a subroutine reference instead:
+
+        ['feature1','Turn on feature #1"],
+        ['feature2','Turn on feature #2"],
+
+        ['GUI:screen', 'Next Screen Title', 
+         doif => sub { 
+           return ($_[1]->qwparam('feature1') && $_[1]->qwparam('feature2'));
+        }]
+
 =item GUI:otherargs_text
 
   EG:  ['GUI:otherargs', 'Files to process:']
@@ -725,6 +999,28 @@ Note that this differs from the Getopt::Long's implementation of the
 auto_help token in that the information is pulled from the extended
 GetOptions called instead of the pod documentation.
 
+The display_help token will automatically add the following options to
+the options the application will accept, and will catch and process
+them as well.
+
+=over
+
+=item -h
+
+Command line help preferring short options if present in the help
+specification.
+
+=item --help
+
+Command line help preferring long options if present in the help
+specification.
+
+=item --help-full
+
+Shows all available option names for a given option
+
+=back
+
 =item capture_output
 
 This tells the Getopt::GUI::Long module that it should caputure the
@@ -748,7 +1044,7 @@ LocalOptionsMap functions should be copied to your perl script.
       if (eval {require Getopt::GUI::Long;}) {
   	import Getopt::GUI::Long;
         # optional configure call
-	Getopt::Long::Configure(qw(display_help no_ignore_case capture_output));
+	Getopt::GUI::Long::Configure(qw(display_help no_ignore_case capture_output));
   	return GetOptions(@_);
       }
       require Getopt::Long;
@@ -771,6 +1067,11 @@ LocalOptionsMap functions should be copied to your perl script.
       return @opts;
   }
 
+=head1 EXAMPLES
+
+See the getopttest program in the examples directory for an exmaple
+script that uses a lot of these features.
+
 =head1 AUTHOR
 
 Wes Hardaker, hardaker@users.sourceforge.net
